@@ -408,7 +408,7 @@ def post_input_to_workflow(ip_port: str, data: str) -> int:
     Returns:
     - int:
         0 if the HTTP response code is 200,
-        2 if the HTTP response code is 202,
+        2 if the HTTP response code is 202, and worklow is starting
         1 for any other error or non-expected code
     """
 
@@ -464,6 +464,12 @@ def post_input_to_workflow(ip_port: str, data: str) -> int:
             print("POST succeeded with HTTP 200")
             return 0
         elif http_code == "202":
+            http_code = result.stdout[-3:]
+            response_json = json.loads(response_body)
+            message = response_json.get("_message", "")
+            if message == "The workflow is already running":
+                print("error POST Workflow already running")
+                return 1
             print("POST succeeded with HTTP 202 (accepted)")
             return 2
         else:
